==> org.eclipse.papyrus.uml.diagram.usecase.source_3.0.0.201706140736.jar: org/eclipse/papyrus/uml/diagram/usecase/custom/edit/parts/UseCaseNodeEditPart.java <==
/*****************************************************************************
 * Copyright (c) 2016 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   CEA LIST - Initial API and implementation
 *   Mickael ADAM (ALL4TEC) mickael.adam@all4tec.net - add missing edit Policy
 *****************************************************************************/
package org.eclipse.papyrus.uml.diagram.usecase.custom.edit.parts;

import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.papyrus.uml.diagram.common.editparts.RoundedCompartmentEditPart;
import org.eclipse.papyrus.uml.diagram.common.editpolicies.ShowHideClassifierContentsEditPolicy;

/**
 * Abstract EditPart for UseCase nodes.
 */
abstract public class UseCaseNodeEditPart extends RoundedCompartmentEditPart {

	/**
	 * Constructor.
	 *
	 * @param view
	 */
	public UseCaseNodeEditPart(final View view) {
		super(view);
	}

	/**
	 * {@inheritDoc}
	 * 
	 * Add missing edit policy to show/hide contents (Bug 489118)
	 * 
	 * @see org.eclipse.papyrus.uml.diagram.common.editparts.RoundedCompartmentEditPart#createDefaultEditPolicies()
	 *
	 */
	@Override
	protected void createDefaultEditPolicies() {
		super.createDefaultEditPolicies();
		installEditPolicy(ShowHideClassifierContentsEditPolicy.SHOW_HIDE_CLASSIFIER_CONTENTS_POLICY, new ShowHideClassifierContentsEditPolicy());
	}

	/**
	 * @see org.eclipse.papyrus.uml.diagram.common.editparts.RoundedCompartmentEditPart#getDefaultIsOvalValue()
	 *
	 * @return The default value for isOval property.
	 */
	@Override
	protected boolean getDefaultIsOvalValue() {
		return true;
	}

}

==> org.eclipse.papyrus.uml.diagram.usecase.source_4.0.0.201806130934.jar: org/eclipse/papyrus/uml/diagram/usecase/custom/edit/parts/UseCaseNodeEditPart.java <==
/*****************************************************************************
 * Copyright (c) 2016 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   CEA LIST - Initial API and implementation
 *   Mickael ADAM (ALL4TEC) mickael.adam@all4tec.net - add missing edit Policy
 *****************************************************************************/
package org.eclipse.papyrus.uml.diagram.usecase.custom.edit.parts;

import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.papyrus.uml.diagram.common.editparts.RoundedCompartmentEditPart;
import org.eclipse.papyrus.uml.diagram.common.editpolicies.ShowHideClassifierContentsEditPolicy;

/**
 * Abstract EditPart for UseCase nodes.
 */
public abstract class UseCaseNodeEditPart extends RoundedCompartmentEditPart {

	/**
	 * Constructor.
	 *
	 * @param view
	 */
	public UseCaseNodeEditPart(final View view) {
		super(view);
	}

	/**
	 * {@inheritDoc}
	 * 
	 * Add missing edit policy to show/hide contents (Bug 489118)
	 * 
	 * @see org.eclipse.papyrus.uml.diagram.common.editparts.RoundedCompartmentEditPart#createDefaultEditPolicies()
	 *
	 */
	@Override
	protected void createDefaultEditPolicies() {
		super.createDefaultEditPolicies();
		installEditPolicy(ShowHideClassifierContentsEditPolicy.SHOW_HIDE_CLASSIFIER_CONTENTS_POLICY, new ShowHideClassifierContentsEditPolicy());
	}

	/**
	 * @see org.eclipse.papyrus.uml.diagram.common.editparts.RoundedCompartmentEditPart#getDefaultIsOvalValue()
	 *
	 * @return The default value for isOval property.
	 */
	@Override
	protected boolean getDefaultIsOvalValue() {
		return true;
	}

}
